@@ -16,7 +16,6 @@ from wetterdienst.enumerations.parameter_enumeration import Parameter
 from wetterdienst.enumerations.period_type_enumeration import PeriodType
 from wetterdienst.enumerations.time_resolution_enumeration import TimeResolution
 from wetterdienst.additionals.functions import (
-    cast_to_list,
     parse_enumeration_from_template,
 )
 from wetterdienst.exceptions import InvalidParameterCombination, StartDateEndDateError
@@ -58,23 +57,24 @@ class DWDStationRequest:
         Special handling for period type. If start_date/end_date are given all period
         types are considered and merged together and the data is filtered for the given
         dates afterwards.
-        Args:
-            station_ids: definition of stations by str, int or list of str/int,
-            will be parsed to list of int
-            parameter: str or parameter enumeration defining the requested parameter
-            time_resolution: str or time resolution enumeration defining the requested
-            time resolution
-            period_type: str or period type enumeration defining the requested
-            period type
-            start_date: replacement for period type to define exact time of
-            requested data
-            end_date: replacement for period type to define exact time of requested data
-            prefer_local: definition if data should rather be taken from a local source
-            write_file: should data be written to a local file
-            folder: place where file lists (and station data) are stored
-            tidy_data: reshape DataFrame to a more tidy, row based version of data
-            humanize_column_names: replace column names by more meaningful ones
-            create_new_file_index: definition if the file index should be recreated
+
+        :param station_ids: definition of stations by str, int or list of str/int,
+                            will be parsed to list of int
+        :param parameter:           Observation measure
+        :param time_resolution:     Frequency/granularity of measurement interval
+        :param period_type:         Recent or historical files
+        :param start_date:          Replacement for period type to define exact time
+                                    of requested data
+        :param end_date:            Replacement for period type to define exact time
+                                    of requested data
+        :param prefer_local:        Definition if data should rather be taken from a
+                                    local source
+        :param write_file:          Should data be written to a local file
+        :param folder:              Place where file lists (and station data) are stored
+        :param tidy_data:           Reshape DataFrame to a more tidy
+                                    and row-based version of data
+        :param humanize_column_names: Replace column names by more meaningful ones
+        :param create_new_file_index: Definition if the file index should be recreated
         """
 
         if not (period_type or start_date or end_date):
@@ -84,15 +84,15 @@ class DWDStationRequest:
             )
 
         try:
-            self.station_ids = [
-                int(station_id) for station_id in cast_to_list(station_ids)
-            ]
+            self.station_ids = pd.Series(station_ids).astype(int).tolist()
         except ValueError:
             raise ValueError("List of station id's can not be parsed to integers.")
 
-        self.parameter = []
-        for p in cast_to_list(parameter):
-            self.parameter.append(parse_enumeration_from_template(p, Parameter))
+        self.parameter = (
+            pd.Series(parameter)
+            .apply(parse_enumeration_from_template, args=(Parameter,))
+            .tolist()
+        )
 
         self.time_resolution = parse_enumeration_from_template(
             time_resolution, TimeResolution
@@ -104,19 +104,12 @@ class DWDStationRequest:
 
         if period_type:
             # For the case that a period_type is given, parse the period type(s)
-            self.period_type = []
-            for pt in cast_to_list(period_type):
-                if pt is None:
-                    self.period_type.append(None)
-                else:
-                    self.period_type.append(
-                        parse_enumeration_from_template(pt, PeriodType)
-                    )
-
-            # Additional sorting required for self.period_type to ensure that for
-            # multiple periods the data is first sourced from historical
-            self.period_type = sorted(self.period_type)
-
+            self.period_type = (
+                pd.Series(period_type)
+                .apply(parse_enumeration_from_template, args=(PeriodType,))
+                .sort_values()
+                .tolist()
+            )
         else:
             # working with ranges of data means expecting data to be laying between
             # periods, thus including all periods
@@ -179,13 +172,9 @@ class DWDStationRequest:
         Method to collect data for a defined request. The function is build as generator
         in order to not cloak the memory thus if the user wants the data as one pandas
         DataFrame the generator has to be casted to a DataFrame manually via
-        pd.concat(list(request.collect_data([...])).
+        pd.concat(list(request.collect_data()).
 
-        Args:
-            same as init
-
-        Returns:
-            via a generator per station a pandas.DataFrame
+        :return: A generator yielding a pandas.DataFrame per station.
         """
         if self.create_new_file_index:
             reset_file_index_cache()
@@ -252,7 +241,7 @@ class DWDStationRequest:
 
 class DWDRadolanRequest:
     """
-    API for DWD RADOLAN data requests
+    API for DWD RADOLAN data requests.
     """
 
     def __init__(
@@ -264,8 +253,22 @@ class DWDRadolanRequest:
         prefer_local: bool = False,
         write_file: bool = False,
         folder: Union[str, Path] = DWD_FOLDER_MAIN,
-    ):
+    ) -> None:
+        """
 
+        :param time_resolution: Time resolution enumeration, either hourly or daily
+        :param date_times:      List of datetimes for which RADOLAN is requested.
+                                Minutes have o be defined (HOUR:50), otherwise rounded
+                                to 50 minutes as of its provision.
+        :param start_date:      Alternative to datetimes, giving a start and end date
+        :param end_date:        Alternative to datetimes, giving a start and end date
+        :param prefer_local:    RADOLAN should rather be loaded from disk, for
+                                processing purposes
+        :param write_file:      File should be stored on drive
+        :param folder:          Folder where to store RADOLAN data
+
+        :return:                Nothing for now.
+        """
         time_resolution = parse_enumeration_from_template(
             time_resolution, TimeResolution
         )
@@ -319,8 +322,7 @@ class DWDRadolanRequest:
         """
         Function used to get the data for the request returned as generator.
 
-        Returns:
-            for each datetime the same datetime and file in bytes
+        :return: For each datetime, the same datetime and file in bytes
         """
         for date_time in self.date_times:
             _, file_in_bytes = collect_radolan_data(
