@@ -26,22 +26,21 @@ def metadata_for_climate_observations(
 ) -> pd.DataFrame:
     """
     A main function to retrieve metadata for a set of parameters that creates a
-        corresponding csv.
+    corresponding csv.
     STATE information is added to metadata for cases where there's no such named
     column (e.g. STATE) in the pandas.DataFrame.
     For this purpose we use daily precipitation data. That has two reasons:
-     - daily precipitation data has a STATE information combined with a city
-     - daily precipitation data is the most common data served by the DWD
-    Args:
-        parameter: observation measure
-        time_resolution: frequency/granularity of measurement interval
-        period_type: recent or historical files
-        create_new_meta_index: if true: a new meta index for metadata will
-         be created
-        create_new_file_index: if true: a new file index for metadata will
-         be created
-    Returns:
-        pandas.DataFrame with metadata for selected parameters
+
+    - daily precipitation data has a STATE information combined with a city
+    - daily precipitation data is the most common data served by the DWD
+
+    :param parameter:               Observation measure
+    :param time_resolution:         Frequency/granularity of measurement interval
+    :param period_type:             Recent or historical files
+    :param create_new_meta_index:   Create a new meta index for metadata
+    :param create_new_file_index:   Create a new file index
+
+    :return: List of stations for selected parameters
     """
     if create_new_meta_index:
         reset_meta_index_cache()
